package com.ynet.life.credit.business;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEException;
import com.ynet.gene.data.IndexedCollection;
import com.ynet.gene.data.KeyedCollection;
import com.ynet.gene.log.GENELog;
import com.ynet.life.base.LifeAction;
import com.ynet.life.credit.util.DESutils;
import com.ynet.life.util.PropertiesFile;
import java.io.IOException;
import java.net.URLEncoder;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Iterator;
import java.util.Properties;
import net.sf.json.JSONArray;
import net.sf.json.JSONObject;
import org.apache.commons.lang.StringEscapeUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.http.client.ClientProtocolException;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.impl.client.DefaultHttpClient;
import org.apache.http.util.EntityUtils;

/* loaded from: com_ynet_life_credit_business.jar:com/ynet/life/credit/business/GetCorInfoInterfaceAction.class */
public class GetCorInfoInterfaceAction extends LifeAction {
    public int type;
    public String inputParam;
    public String resultList;
    private String url;
    private String appID;
    private String appSecret;
    private String profile;
    private static final String COR_DIRECTORY_ERROR_CODE = "IERROR0001";
    private static final String COR_BASIC_ERROR_CODE = "IERROR0002";
    private static final String COR_PATENT_ERROR_CODE = "IERROR0003";
    private static final String COR_LEADING_ERROR_CODE = "IERROR0004";
    private static final String COR_QUALIFICATIONS_ERROR_CODE = "IERROR0005";
    private static final String COR_DIRECTORY_LOG = "【【企业名录信息接口】】";
    private static final String COR_BASIC_LOG = "【【企业基本信息接口】】";
    private static final String COR_PATENT_LOG = "【【专利信息接口】】";
    private static final String COR_LEADING_LOG = "【【四级领军人才认定信息接口】】";
    private static final String COR_QUALIFICATIONS_LOG = "【【企业资质认定信息接口】】";
    private String page = "";

    public String execute(Context context) throws GENEException {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
        Calendar cal = Calendar.getInstance();
        context.put("d2_create_time", sdf.format(cal.getTime()));
        String param = context.getDataValue(this.inputParam).toString();
        if (this.type == 1) {
            this.page = context.getDataValue("count").toString();
        } else {
            this.page = "";
        }
        IndexedCollection outputIColl = (IndexedCollection) context.getDataElement(this.resultList);
        getInterfaceParams(this.type);
        handleReturnData(this.type, context, param, outputIColl);
        return "0";
    }

    private void getInterfaceParams(int type) throws GENEException {
        String interfaceName;
        Properties bankDBSourceProperties = PropertiesFile.getProperties("/properties/getCorInfoInterfacePath.properties");
        this.profile = bankDBSourceProperties.getProperty("profile");
        switch (type) {
            case 1:
                interfaceName = "Directory";
                break;
            case 2:
                interfaceName = "Basic";
                break;
            case 3:
                interfaceName = "Patent";
                break;
            case 4:
                interfaceName = "Leading";
                break;
            case 5:
                interfaceName = "Qualifications";
                break;
            default:
                throw new GENEException(getErrorCode(type), String.valueOf(getLogComponent(type)) + "接口类型Type有误");
        }
        this.url = bankDBSourceProperties.getProperty(String.valueOf(this.profile) + interfaceName + "Url");
        this.appID = bankDBSourceProperties.getProperty(String.valueOf(this.profile) + "AppID");
        this.appSecret = bankDBSourceProperties.getProperty(String.valueOf(this.profile) + "AppSecret");
    }

    private void handleReturnData(int type, Context context, String param, IndexedCollection outputIColl) throws GENEException {
        String value;
        try {
            String result = getReturnData(this.url, this.appID, this.appSecret, param, context);
            if (StringUtils.isEmpty(result)) {
                throw new GENEException(getErrorCode(type), String.valueOf(getLogComponent(type)) + "返回结果为空");
            }
            JSONObject jsonOb = JSONObject.fromObject(result);
            if (jsonOb != null) {
                String code = jsonOb.getString("code");
                if ("0".equals(code)) {
                    String strJson = jsonOb.getString("data");
                    StringEscapeUtils.unescapeJava(strJson);
                    GENELog.log(getLogComponent(type), GENELog.INFO, 0, "返回结果==getEntity".concat(String.valueOf(strJson)));
                    GENELog.log(getLogComponent(type), GENELog.INFO, 0, "请求地址==" + this.url);
                    GENELog.log(getLogComponent(type), GENELog.INFO, 0, "请求密钥==" + this.appSecret);
                    GENELog.log(getLogComponent(type), GENELog.INFO, 0, "返回结果==des" + DESutils.decrypt(strJson, this.appSecret));
                    JSONObject jsonObj = JSONObject.fromObject(DESutils.decrypt(strJson, this.appSecret));
                    GENELog.log(getLogComponent(type), GENELog.INFO, 0, "返回结果==jsonObj" + jsonObj.toString());
                    JSONArray jsonArray = jsonObj.getJSONArray("data");
                    GENELog.log(getLogComponent(type), GENELog.INFO, 0, "返回结果==jsonArray" + jsonArray.toString());
                    Iterator<Object> it = jsonArray.iterator();
                    while (it.hasNext()) {
                        KeyedCollection singleRecord = new KeyedCollection();
                        JSONObject data = JSONObject.fromObject(it.next());
                        Iterator<String> itor = data.keys();
                        while (itor.hasNext()) {
                            try {
                                String key = itor.next();
                                if (data.get(key) == null || "null".equals(data.get(key).toString())) {
                                    value = null;
                                } else {
                                    value = data.get(key).toString();
                                }
                                if ("k42".equals(key)) {
                                    value = StringUtils.substringBefore(value, ",");
                                }
                                if ("entername".equals(key)) {
                                    value = value.replace("(", "（").replace(")", "）");
                                }
                                singleRecord.addDataField(key, value);
                                if ("patenttype".equals(key)) {
                                    GENELog.log(getLogComponent(type), GENELog.INFO, 0, "返回结果==value2".concat(String.valueOf(value)));
                                    GENELog.log(getLogComponent(type), GENELog.INFO, 0, "返回结果==get2" + data.get(key));
                                    GENELog.log(getLogComponent(type), GENELog.INFO, 0, "返回结果==toString2" + data.get(key).toString());
                                }
                            } catch (Exception unused) {
                            }
                        }
                        outputIColl.addDataElement(singleRecord);
                    }
                    return;
                }
                String message = jsonOb.getString("msg");
                GENELog.log(getLogComponent(type), GENELog.INFO, 0, "接口调用失败：".concat(String.valueOf(message)));
                return;
            }
            GENELog.log(getLogComponent(type), GENELog.INFO, 0, "JSON格式错误" + result.toString());
        } catch (Exception e1) {
            throw new GENEException(getErrorCode(type), String.valueOf(getLogComponent(type)) + "调用异常", e1);
        }
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v13, types: [java.lang.StringBuilder] */
    /* JADX WARN: Type inference failed for: r0v5, types: [java.lang.String] */
    /* JADX WARN: Type inference failed for: r0v52, types: [java.lang.Object] */
    /* JADX WARN: Type inference failed for: r0v6, types: [java.lang.Exception] */
    private String getReturnData(String url, String appID, String appSecret, String param, Context context) throws Exception {
        String url2;
        GENELog.log(getLogComponent(this.type), GENELog.INFO, 0, "入参==url:" + url + " || appID:" + appID + " || appSecret:" + appSecret + " || inputParam:" + param);
        String result = "";
        ?? l = Long.toString(System.currentTimeMillis() / 1000);
        try {
            String authID = DESutils.encrypt(String.valueOf(appID) + "," + l, appSecret);
            if (this.type == 1) {
                url2 = String.valueOf(url) + "?timerange=" + URLEncoder.encode(param, "utf-8") + "&page=" + URLEncoder.encode(this.page, "utf-8");
            } else {
                url2 = String.valueOf(url) + "?organcode=" + URLEncoder.encode(param, "utf-8");
            }
            GENELog.log(getLogComponent(this.type), GENELog.INFO, 0, "url==".concat(String.valueOf(url2)));
            GENELog.log(getLogComponent(this.type), GENELog.INFO, 0, "authID==".concat(String.valueOf(authID)));
            HttpGet httpGet = new HttpGet(url2);
            DefaultHttpClient httpClient = new DefaultHttpClient();
            httpGet.setHeader("AuthID", authID);
            GENELog.log(getLogComponent(this.type), GENELog.INFO, 0, "httpGet==".concat(String.valueOf(httpGet)));
            result = EntityUtils.toString(httpClient.execute(httpGet).getEntity(), "utf-8");
            GENELog.log(getLogComponent(this.type), GENELog.INFO, 0, "返回结果==result".concat(String.valueOf(result)));
            context.put("serName", url2);
            JSONObject jsParam = new JSONObject();
            jsParam.put("appID", appID);
            jsParam.put("appSecret", this.appSecret);
            if (this.type == 1) {
                jsParam.put("timerange", param);
            } else {
                jsParam.put("organcode", param);
            }
            context.put("accesstoken", jsParam.toString());
            l = context.put("serResult", result);
        } catch (ClientProtocolException e) {
            System.err.println("Http协议出现问题");
            e.printStackTrace();
        } catch (IOException e2) {
            System.err.println("IO异常");
            e2.printStackTrace();
        } catch (Exception e3) {
            l.printStackTrace();
        }
        return result;
    }

    private String getErrorCode(int type) {
        String result;
        switch (type) {
            case 1:
                result = COR_DIRECTORY_ERROR_CODE;
                break;
            case 2:
                result = COR_BASIC_ERROR_CODE;
                break;
            case 3:
                result = COR_PATENT_ERROR_CODE;
                break;
            case 4:
                result = COR_LEADING_ERROR_CODE;
                break;
            case 5:
                result = COR_QUALIFICATIONS_ERROR_CODE;
                break;
            default:
                result = "";
                break;
        }
        return result;
    }

    private String getLogComponent(int type) {
        String result;
        switch (type) {
            case 1:
                result = COR_DIRECTORY_LOG;
                break;
            case 2:
                result = COR_BASIC_LOG;
                break;
            case 3:
                result = COR_PATENT_LOG;
                break;
            case 4:
                result = COR_LEADING_LOG;
                break;
            case 5:
                result = COR_QUALIFICATIONS_LOG;
                break;
            default:
                result = "";
                break;
        }
        return result;
    }

    public int getType() {
        return this.type;
    }

    public String getInputParam() {
        return this.inputParam;
    }

    public String getResultList() {
        return this.resultList;
    }

    public void setInputParam(String inputParam) {
        this.inputParam = inputParam;
    }

    public void setType(int type) {
        this.type = type;
    }

    public void setResultList(String resultList) {
        this.resultList = resultList;
    }
}
